@@ -1,14 +1,12 @@
-/* $Id: example.c,v 1.5 1998/07/05 17:08:59 sverrehu Exp $ */
-/**************************************************************************
- *
- *  FILE            example.c
- *
- *  DESCRIPTION     Sample source code using the shhopt-library to parse
- *                  command line options.
- *
- *  WRITTEN BY      Sverre H. Huseby <sverrehu@online.no>
- *
- **************************************************************************/
+/* $Id: example.c,v 1.7 2002/03/02 19:56:18 sverrehu Exp $ */
+/*------------------------------------------------------------------------
+ |  FILE            example.c
+ |
+ |  DESCRIPTION     Sample source code using the shhopt-library to parse
+ |                  command line options.
+ |
+ |  WRITTEN BY      Sverre H. Huseby <shh@thathost.com>
+ +----------------------------------------------------------------------*/
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -16,11 +14,9 @@
 
 #include "shhopt.h"
 
-/**************************************************************************
- *                                                                        *
- *                   P R I V A T E    F U N C T I O N S                   *
- *                                                                        *
- **************************************************************************/
+/*-----------------------------------------------------------------------+
+|  PRIVATE DATA                                                          |
++-----------------------------------------------------------------------*/
 
 /* called by -N or --number-func */
 static void
@@ -97,13 +93,9 @@ usage(void)
     exit(1);
 }
 
-
-
-/**************************************************************************
- *                                                                        *
- *                    P U B L I C    F U N C T I O N S                    *
- *                                                                        *
- **************************************************************************/
+/*-----------------------------------------------------------------------+
+|  PUBLIC FUNCTIONS                                                      |
++-----------------------------------------------------------------------*/
 
 int
 main(int argc, char *argv[])
