@@ -1,19 +1,18 @@
-/* $Id: shhopt.c,v 1.4 1998/07/05 17:08:59 sverrehu Exp $ */
-/**************************************************************************
- *
- *  FILE            shhopt.c
- *
- *  DESCRIPTION     Functions for parsing command line arguments. Values
- *                  of miscellaneous types may be stored in variables,
- *                  or passed to functions as specified.
- *
- *  REQUIREMENTS    Some systems lack the ANSI C -function strtoul. If your
- *                  system is one of those, you'll ned to write one yourself,
- *                  or get the GNU liberty-library (from prep.ai.mit.edu).
- *
- *  WRITTEN BY      Sverre H. Huseby <sverrehu@online.no>
- *
- **************************************************************************/
+/* $Id: shhopt.c,v 1.6 2002/03/02 19:56:18 sverrehu Exp $ */
+/*------------------------------------------------------------------------
+ |  FILE            shhopt.c
+ |
+ |  DESCRIPTION     Functions for parsing command line arguments. Values
+ |                  of miscellaneous types may be stored in variables,
+ |                  or passed to functions as specified.
+ |
+ |  REQUIREMENTS    Some systems lack the ANSI C -function strtoul. If
+ |                  your system is one of those, you'll ned to write
+ |                  one yourself, or get the GNU liberty-library (from
+ |                  ftp://ftp.gnu.org/pub/gnu/).
+ |
+ |  WRITTEN BY      Sverre H. Huseby <shh@thathost.com>
+ +----------------------------------------------------------------------*/
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -25,34 +24,26 @@
 
 #include "shhopt.h"
 
-/**************************************************************************
- *                                                                        *
- *                       P R I V A T E    D A T A                         *
- *                                                                        *
- **************************************************************************/
+/*-----------------------------------------------------------------------+
+|  PRIVATE DATA                                                          |
++-----------------------------------------------------------------------*/
 
 static void optFatalFunc(const char *, ...);
 static void (*optFatal)(const char *format, ...) = optFatalFunc;
 
+/*-----------------------------------------------------------------------+
+|  PRIVATE FUNCTIONS                                                     |
++-----------------------------------------------------------------------*/
 
-
-/**************************************************************************
- *                                                                        *
- *                   P R I V A T E    F U N C T I O N S                   *
- *                                                                        *
- **************************************************************************/
-
-/*-------------------------------------------------------------------------
- *
- *  NAME          optFatalFunc
- *
- *  FUNCTION      Show given message and abort the program.
- *
- *  INPUT         format, ...
- *                        Arguments used as with printf().
- *
- *  RETURNS       Never returns. The program is aborted.
- *
+/*------------------------------------------------------------------------
+ |  NAME          optFatalFunc
+ |
+ |  FUNCTION      Show given message and abort the program.
+ |
+ |  INPUT         format, ...
+ |                        Arguments used as with printf().
+ |
+ |  RETURNS       Never returns. The program is aborted.
  */
 void
 optFatalFunc(const char *format, ...)
@@ -66,21 +57,17 @@ optFatalFunc(const char *format, ...)
     exit(99);
 }
 
-
-
-/*-------------------------------------------------------------------------
- *
- *  NAME          optStructCount
- *
- *  FUNCTION      Get number of options in a optStruct.
- *
- *  INPUT         opt     array of possible options.
- *
- *  RETURNS       Number of options in the given array.
- *
- *  DESCRIPTION   Count elements in an optStruct-array. The strcture must
- *                be ended using an element of type OPT_END.
- *
+/*------------------------------------------------------------------------
+ |  NAME          optStructCount
+ |
+ |  FUNCTION      Get number of options in a optStruct.
+ |
+ |  INPUT         opt     array of possible options.
+ |
+ |  RETURNS       Number of options in the given array.
+ |
+ |  DESCRIPTION   Count elements in an optStruct-array. The strcture must
+ |                be ended using an element of type OPT_END.
  */
 static int
 optStructCount(optStruct opt[])
@@ -92,29 +79,25 @@ optStructCount(optStruct opt[])
     return ret;
 }
 
-
-
-/*-------------------------------------------------------------------------
- *
- *  NAME          optMatch
- *
- *  FUNCTION      Find a matching option.
- *
- *  INPUT         opt     array of possible options.
- *                s       string to match, without `-' or `--'.
- *                lng     match long option, otherwise short.
- *
- *  RETURNS       Index to the option if found, -1 if not found.
- *
- *  DESCRIPTION   Short options are matched from the first character in
- *                the given string.
- *
+/*------------------------------------------------------------------------
+ |  NAME          optMatch
+ |
+ |  FUNCTION      Find a matching option.
+ |
+ |  INPUT         opt     array of possible options.
+ |                s       string to match, without `-' or `--'.
+ |                lng     match long option, otherwise short.
+ |
+ |  RETURNS       Index to the option if found, -1 if not found.
+ |
+ |  DESCRIPTION   Short options are matched from the first character in
+ |                the given string.
  */
 static int
 optMatch(optStruct opt[], const char *s, int lng)
 {
-    int  nopt, q, matchlen = 0;
-    char *p;
+    int        nopt, q, matchlen = 0;
+    const char *p;
 
     nopt = optStructCount(opt);
     if (lng) {
@@ -139,19 +122,15 @@ optMatch(optStruct opt[], const char *s, int lng)
     return -1;
 }
 
-
-
-/*-------------------------------------------------------------------------
- *
- *  NAME          optString
- *
- *  FUNCTION      Return a (static) string with the option name.
- *
- *  INPUT         opt     the option to stringify.
- *                lng     is it a long option?
- *
- *  RETURNS       Pointer to static string.
- *
+/*------------------------------------------------------------------------
+ |  NAME          optString
+ |
+ |  FUNCTION      Return a (static) string with the option name.
+ |
+ |  INPUT         opt     the option to stringify.
+ |                lng     is it a long option?
+ |
+ |  RETURNS       Pointer to static string.
  */
 static char *
 optString(optStruct *opt, int lng)
@@ -169,18 +148,14 @@ optString(optStruct *opt, int lng)
     return ret;
 }
 
-
-
-/*-------------------------------------------------------------------------
- *
- *  NAME          optNeedsArgument
- *
- *  FUNCTION      Check if an option requires an argument.
- *
- *  INPUT         opt     the option to check.
- *
- *  RETURNS       Boolean value.
- *
+/*------------------------------------------------------------------------
+ |  NAME          optNeedsArgument
+ |
+ |  FUNCTION      Check if an option requires an argument.
+ |
+ |  INPUT         opt     the option to check.
+ |
+ |  RETURNS       Boolean value.
  */
 static int
 optNeedsArgument(optStruct *opt)
@@ -192,21 +167,17 @@ optNeedsArgument(optStruct *opt)
 	|| opt->type == OPT_ULONG;
 }
 
-
-
-/*-------------------------------------------------------------------------
- *
- *  NAME          argvRemove
- *
- *  FUNCTION      Remove an entry from an argv-array.
- *
- *  INPUT         argc    pointer to number of options.
- *                argv    array of option-/argument-strings.
- *                i       index of option to remove.
- *
- *  OUTPUT        argc    new argument count.
- *                argv    array with given argument removed.
- *
+/*------------------------------------------------------------------------
+ |  NAME          argvRemove
+ |
+ |  FUNCTION      Remove an entry from an argv-array.
+ |
+ |  INPUT         argc    pointer to number of options.
+ |                argv    array of option-/argument-strings.
+ |                i       index of option to remove.
+ |
+ |  OUTPUT        argc    new argument count.
+ |                argv    array with given argument removed.
  */
 static void
 argvRemove(int *argc, char *argv[], int i)
@@ -218,20 +189,16 @@ argvRemove(int *argc, char *argv[], int i)
     --*argc;
 }
 
-
-
-/*-------------------------------------------------------------------------
- *
- *  NAME          optExecute
- *
- *  FUNCTION      Perform the action of an option.
- *
- *  INPUT         opt     array of possible options.
- *                arg     argument to option, if it applies.
- *                lng     was the option given as a long option?
- *
- *  RETURNS       Nothing. Aborts in case of error.
- *
+/*------------------------------------------------------------------------
+ |  NAME          optExecute
+ |
+ |  FUNCTION      Perform the action of an option.
+ |
+ |  INPUT         opt     array of possible options.
+ |                arg     argument to option, if it applies.
+ |                lng     was the option given as a long option?
+ |
+ |  RETURNS       Nothing. Aborts in case of error.
  */
 void
 optExecute(optStruct *opt, char *arg, int lng)
@@ -308,26 +275,20 @@ optExecute(optStruct *opt, char *arg, int lng)
     }
 }
 
+/*-----------------------------------------------------------------------+
+|  PUBLIC FUNCTIONS                                                      |
++-----------------------------------------------------------------------*/
 
-
-/**************************************************************************
- *                                                                        *
- *                    P U B L I C    F U N C T I O N S                    *
- *                                                                        *
- **************************************************************************/
-
-/*-------------------------------------------------------------------------
- *
- *  NAME          optSetFatalFunc
- *
- *  FUNCTION      Set function used to display error message and exit.
- *
- *  SYNOPSIS      #include "shhopt.h"
- *                void optSetFatalFunc(void (*f)(const char *, ...));
- *
- *  INPUT         f       function accepting printf()'like parameters,
- *                        that _must_ abort the program.
- *
+/*------------------------------------------------------------------------
+ |  NAME          optSetFatalFunc
+ |
+ |  FUNCTION      Set function used to display error message and exit.
+ |
+ |  SYNOPSIS      #include "shhopt.h"
+ |                void optSetFatalFunc(void (*f)(const char *, ...));
+ |
+ |  INPUT         f       function accepting printf()'like parameters,
+ |                        that _must_ abort the program.
  */
 void
 optSetFatalFunc(void (*f)(const char *, ...))
@@ -335,41 +296,37 @@ optSetFatalFunc(void (*f)(const char *, ...))
     optFatal = f;
 }
 
-
-
-/*-------------------------------------------------------------------------
- *
- *  NAME          optParseOptions
- *
- *  FUNCTION      Parse commandline options.
- *
- *  SYNOPSIS      #include "shhopt.h"
- *                void optParseOptions(int *argc, char *argv[],
- *                                     optStruct opt[], int allowNegNum);
- *
- *  INPUT         argc    Pointer to number of options.
- *                argv    Array of option-/argument-strings.
- *                opt     Array of possible options.
- *                allowNegNum
- *                        a negative number is not to be taken as
- *                        an option.
- *
- *  OUTPUT        argc    new argument count.
- *                argv    array with arguments removed.
- *
- *  RETURNS       Nothing. Aborts in case of error.
- *
- *  DESCRIPTION   This function checks each option in the argv-array
- *                against strings in the opt-array, and `executes' any
- *                matching action. Any arguments to the options are
- *                extracted and stored in the variables or passed to
- *                functions pointed to by entries in opt.
- *
- *                Options and arguments used are removed from the argv-
- *                array, and argc is decreased accordingly.
- *
- *                Any error leads to program abortion.
- *
+/*------------------------------------------------------------------------
+ |  NAME          optParseOptions
+ |
+ |  FUNCTION      Parse commandline options.
+ |
+ |  SYNOPSIS      #include "shhopt.h"
+ |                void optParseOptions(int *argc, char *argv[],
+ |                                     optStruct opt[], int allowNegNum);
+ |
+ |  INPUT         argc    Pointer to number of options.
+ |                argv    Array of option-/argument-strings.
+ |                opt     Array of possible options.
+ |                allowNegNum
+ |                        a negative number is not to be taken as
+ |                        an option.
+ |
+ |  OUTPUT        argc    new argument count.
+ |                argv    array with arguments removed.
+ |
+ |  RETURNS       Nothing. Aborts in case of error.
+ |
+ |  DESCRIPTION   This function checks each option in the argv-array
+ |                against strings in the opt-array, and `executes' any
+ |                matching action. Any arguments to the options are
+ |                extracted and stored in the variables or passed to
+ |                functions pointed to by entries in opt.
+ |
+ |                Options and arguments used are removed from the argv-
+ |                array, and argc is decreased accordingly.
+ |
+ |                Any error leads to program abortion.
  */
 void
 optParseOptions(int *argc, char *argv[], optStruct opt[], int allowNegNum)
